.. image:: https://img.shields.io/pypi/v/jaraco.imaging.svg
   :target: https://pypi.org/project/jaraco.imaging

.. image:: https://img.shields.io/pypi/pyversions/jaraco.imaging.svg

.. image:: https://img.shields.io/travis/jaraco/jaraco.imaging/master.svg
   :target: https://travis-ci.org/jaraco/jaraco.imaging

.. .. image:: https://img.shields.io/appveyor/ci/jaraco/jaraco-imaging/master.svg
..    :target: https://ci.appveyor.com/project/jaraco/jaraco-imaging/branch/master

.. .. image:: https://readthedocs.org/projects/jaracoimaging/badge/?version=latest
..    :target: https://jaracoimaging.readthedocs.io/en/latest/?badge=latest
